<?php

namespace App\Exceptions;

use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Throwable;
use App\Http\Controllers\JsonResponse;
use App\Services\Exception\ServiceException;
use Illuminate\Auth\AuthenticationException;
use Illuminate\Validation\ValidationException;
use Symfony\Component\HttpKernel\Exception\HttpException;
use App\Lib\Alerting\Facades\Alerting;

class Handler extends ExceptionHandler
{
    /**
     * A list of exception types with their corresponding custom log levels.
     *
     * @var array<class-string<\Throwable>, \Psr\Log\LogLevel::*>
     */
    protected $levels = [
        //
    ];

    /**
     * A list of the exception types that are not reported.
     *
     * @var array<int, class-string<\Throwable>>
     */
    protected $dontReport = [
        //
    ];

    /**
     * A list of the inputs that are never flashed to the session on validation exceptions.
     *
     * @var array<int, string>
     */
    protected $dontFlash = [
        'current_password',
        'password',
        'password_confirmation',
    ];

        /**
     * Report or log an exception.
     *
     * @param \Throwable $exception
     * @return void
     * @throws \Throwable
     */
    public function report(\Throwable $exception)
    {
        parent::report($exception);
        if(!$exception instanceof HttpException && config('app.enable_alert')) {
            Alerting::send($exception);
        }
    }

    /**
     * Register the exception handling callbacks for the application.
     *
     * @return void
     */
    public function register()
    {
        $this->reportable(function (Throwable $e) {
            //
        });
    }

    public function render($request, \Throwable $exception)
    {
        $response = new JsonResponse();
        $response->status = false;

        if ($request->segment(1) === 'api') {
            if ($exception instanceof ValidationException) {
                $response->message = $exception->getMessage();
                return parent::render($request, $exception);
            } else if($exception instanceof ServiceException){
                $response->message = $exception->response->getData()->message;
                return response()->json($response, 500);
            } else if ($exception instanceof AuthenticationException){
                $response->message = $exception->getMessage();
                return response()->json($response, 500);
            }
        }

        return parent::render($request, $exception);
    }

    protected function invalidJson($request, ValidationException $exception)
    {
        if (!($response = $this->invalidApi($request, $exception)))
            return parent::invalidJson($request, $exception);
        return $response;
    }

    protected function invalid($request, ValidationException $exception)
    {
        if (!($response = $this->invalidApi($request, $exception)))
            return parent::invalid($request, $exception);

        return $response;
    }

    private function invalidApi($request, ValidationException $exception)
    {
        if (in_array('api', $request->route()->action['middleware'])) {
            $errors = [];
            foreach ($exception->errors() as $field => $message) {
                $errors[] = [
                    'field' => $field,
                    'message' => $message[0],
                ];
            }

            $response = new JsonResponse();
            $response->errors = $errors;

            return response()->json($response, $exception->status);
        } else {
            return false;
        }
    }
}