<?php

namespace App\Http\Controllers\Admin\Landing;

use App\Http\Controllers\Controller;
use App\Services\Admin\Landing\FormService;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class FormController extends Controller
{
    protected $form;

    public function __construct(FormService $formService) {
        parent::__construct();
        $this->form = $formService;
    }

    public function index(){
        $data = $this->form->getAll();
		return DataTables::of($data)->make();
    }

    public function store(Request $request)
    {
        $request->validate([
			'title' => 'required',
            'document' => 'required|mimes:pdf|max:10000'
        ]);

        $this->response->data = $this->form->createData($request->title, $request->file('document'));
        $this->response->message = __('resources.create_success');
        return $this->json();
    }

    public function detail($id)
    {
        $this->response->data = $this->form->getDataById($id);
        return $this->json();
    }

    public function update(Request $request, $id)
    {
        $request->validate([
			'title' => 'required',
            'document' => 'nullable|mimes:pdf|max:10000'
        ]);

        $this->form->updateData($id, $request->title, $request->file('banner'));
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function delete($id)
    {
        $this->form->deleteData($id);
        $this->response->message = __('resources.delete_success');
		return $this->json();
    }
}
