<?php

namespace App\Http\Controllers\Admin\Landing;

use App\Http\Controllers\Controller;
use App\Services\Admin\Landing\SliderService;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class SliderController extends Controller
{
    protected $slider;

    public function __construct(SliderService $sliderService) {
        parent::__construct();
        $this->slider = $sliderService;
    }

    public function index(){
        $data = $this->slider->getAll();
		return DataTables::of($data)->make();
    }

    public function store(Request $request)
    {        
        $request->validate([
			'title' => 'required',
            'description' => 'required',
            'position' => 'required|integer',
            'banner' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048'
        ]);

        $this->response->data = $this->slider->createData($request->title, $request->description, $request->position, $request->file('banner'));
        $this->response->message = __('resources.create_success');
        return $this->json();
    }

    public function detail($slider)
    {
        $this->response->data = $this->slider->getDataById($slider);
        return $this->json();
    }

    public function update(Request $request, $id)
    {
        $request->validate([
			'title' => 'required',
            'description' => 'required',
            'position' => 'required|integer',
            'banner' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:2048'
        ]);

        $this->slider->updateData($id, $request->title, $request->description, $request->position, $request->file('banner'));
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function delete($id)
    {
        $this->slider->deleteData($id);
        $this->response->message = __('resources.delete_success');
		return $this->json();
    }

    public function update_display($id)
    {
        $this->slider->updateDisplaySlider($id);
        $this->response->message = __('resources.update_success');
        return $this->json();
    }
}
