<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Services\Admin\ScheduleService;
use Yajra\DataTables\DataTables;

class ScheduleController extends Controller
{
    protected $schedule;

    public function __construct(ScheduleService $scheduleService)
    {
        parent::__construct();
        $this->schedule = $scheduleService;
    }

    public function index()
    {
        $data = $this->schedule->getAll();
        return DataTables::of($data)->make();
    }

    public function store(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'speaker' => 'required',
            'description' => 'required',
            'banner' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
            'time' => 'required'
        ]);

        $this->response->data = $this->schedule->createData(
            $request->title,
            $request->speaker,
            $request->description,
            $request->file('banner'),
            $request->time
        );
        $this->response->message = __('resources.create_success');
        return $this->json();
    }

    public function detail($id)
    {
        $this->response->data = $this->schedule->getDatabyId($id);
        return $this->json();
    }

    public function update(Request $request, $id)
    {
        $request->validate([
            'title' => 'required',
            'speaker' => 'required',
            'description' => 'required',
            'banner' => 'nullable|max:2048',
            'time' => 'required'
        ]);

        $this->schedule->updateData(
            $id,
            $request->title,
            $request->speaker,
            $request->description,
            $request->file('banner'),
            $request->time
        );
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function delete($id)
    {
        $this->schedule->deleteData($id);
        $this->response->message = __('resources.delete_success');
        return $this->json();
    }

    public function analysis_history(Request $request)
    {
        return $this->schedule->getDataAnalystHistory($request->startDate, $request->endDate);
    }

    public function detail_analysis_history(Request $request, $id)
    {
        $data = $this->schedule->getDataAnalystHistoryById($id);
        return DataTables::of($data)->make();
    }

    public function analysis_history_filter(Request $request)
    {
        $request->validate([
            'startDate' => ['required'],
            'endDate' => ['required']
        ]);

        return $this->schedule->getDataAnalystHistoryFilter($request->startDate, $request->endDate);
    }

    public function chart()
    {
        $this->response->data = $this->schedule->getDataChart();
        return $this->json();
    }

    public function send_android($id)
    {
        $this->schedule->pushNotificationAndroid($id);
        $this->response->message = __('resources.success_send_notification');
        return $this->json();
    }

    public function send_ios($id)
    {
        $this->schedule->pushNotificationIos($id);
        $this->response->message = __('resources.success_send_notification');
        return $this->json();
    }

    public function detail_schedule($id)
    {
        $this->response->data = $this->schedule->detail_schedule($id);
        return $this->json();
    }

    public function detail_schedule_count($id)
    {
        $this->response->data = $this->schedule->detail_schedule_count($id);
        return $this->json();
    }
}
