<?php

namespace App\Http\Controllers\Agent;

use App\Http\Controllers\Controller;
use App\Models\Agent;
use App\Services\Agent\AgentService;
use Illuminate\Http\Request;

class AgentController extends Controller
{
    protected $agent;

    public function __construct(AgentService $agentService) {
        parent::__construct();
        $this->agent = $agentService;
    }


    public function login(Request $request)
    {
        $request->validate([
            'agent_code' => 'required|string',
            'password' => 'required|string'
        ]);

        $this->response->data = $this->agent->createToken($request->agent_code, $request->password);
        return $this->json();
    }

    public function update_profile(Request $request, Agent $agent){
        $request->validate([
            'username' => 'required|string',
            'email' => 'required',
            'password' => 'nullable|string',
            'phone_number' => 'required',
            'address' => 'required',
            'birth' => 'required',
            'agent_code' => 'required',
        ]);

        $this->agent->updateData($request->agent_code, $request->username, $request->password, $request->email, $request->phone_number, $request->address, $request->birth);
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function updateFirebaseToken(Request $request)
    {
        $this->agent->updateToken(auth()->user()->id, $request->device_token);
        $this->response->message = __('resources.update_success');
        return $this->json();
    }

    public function logout()
    {
        $user = request()->user(); 
        $user->tokens()->where('id', $user->currentAccessToken()->id)->delete();

        $this->response->message = "You have successfully logged out and the token was successfully deleted";
        return $this->json();
    }
}
