<?php

namespace App\Http\Controllers\Landing;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use App\Models\Agent;
use Psr\Log\LoggerInterface;
use Illuminate\Support\Facades\Log;

class AgentController extends Controller
{

    /**
     * @var LoggerInterface
     */
    protected $logger;

    public function __construct() {
        parent::__construct();
        $this->logger = Log::channel('landing-agentController');
    }

    public function register(Request $request)
    {
        $rules = [
            'agent_code' => 'required|unique:agents,agent_code',
            'username' => 'required|string',
            'email' => 'required',
            'password' => 'required|string',
            'phone_number' => 'required',
            'address' => 'required',
            'birth' => 'required'
        ];

        try{
            $validator = Validator::make($request->all(), $rules);
            if ($validator->fails()) {
                $this->code = 400;
                $this->response->status = false;
                $this->response->message = $validator->errors()->first();
                $this->response->errors = $validator->fails();

                $this->logger->error($validator->errors()->first());
                return $this->json();
            }
    
            $data = new Agent($request->all());
            $data->password = bcrypt($request->password);
            $data->save();
            
            $this->code = 201;
            $this->response->message = __('resources.create_success');
        } catch(\Exception $e) {
            $this->code = 500;
            $this->logger->error($e->getMessage());
            $this->response->message = __('resources.create_failed');
        }

        return $this->json();
    }
}
