<?php

namespace App\Http\Controllers;

use App\Models\Role;
use Illuminate\Http\Request;
use Spatie\Permission\Exceptions\RoleAlreadyExists;
use App\Models\Permission;
use App\Models\User;
use App\Exceptions\AppException;

class RoleController extends Controller
{
    public function index(){
        $data = Role::get();

        $this->code = 200;
        $this->response->data = $data;
        return $this->json();
    }

    public function roleAdmin(Request $request){
        $this->response->data = Role::where('guard_name', config('app.admin_guard'))
            ->where(function($query){
                $query->where('id',auth()->user()->id)
                      ->orWhere('name',config('app.whitelabel_role'));
            })
            ->select(['id', 'name as value', 'name as label'])
            ->get();
        
        return $this->json();
    }

    public function roleAdd(Request $request){
        $this->validate($request, [
            'name'  => 'required'
        ]);

        try{
            Role::create([
                'name' => $request->name,
                'guard_name' => config('app.admin_guard')
            ]);
        }catch (RoleAlreadyExists $e){
            throw new RoleAlreadyExists(__('validation.role.exists', ['role' => $request->name]));
        }

        return $this->json();
    }

    public function roleDetail(Request $request, $name){
        try{
            $role = Role::where('name', $name)->first();

            if ($role)
            {
                $this->response->data->role = $role;
                $this->response->data->permissions = Permission::with(['roles' => function($query) use($role){
                    $query->where('id', '=', $role->id);
                }])
                ->where('guard_name', config('app.admin_guard'))
                ->orderBy('name')->get();
            }else{
                $this->response->status = false;
                $this->response->message = "Not Found";
            }
        }catch (\Exception $e){
            $this->response->status = false;
            $this->response->message = $e->getMessage();
        }

        return $this->json();
    }

    public function changeRole(Request $request, User $user){
        $request->validate([
            'role' => 'required',
        ]);

        $role = Role::findById($request->role_select['id'], config('app.admin_guard'));
        $user->syncRoles($role);

        return $this->json();
    }

    public function roleEdit(Request $request){
        $this->validate($request, [
            'id' => 'required|exists:roles',
            'name' => 'required|exists:roles',
            'permissions' => 'required|array'
        ]);

        $role = Role::findById($request->id);
        $permissions = collect($request->permissions)->where('checked', true)->pluck('name')->toArray();
        $role->syncPermissions($permissions);

        return $this->json();
    }

    public function roleDelete($name){
        if ($name === config('app.super_admin_role'))
            throw new AppException(__('resources.delete_failed', ['role' => $name]), 400);

        $role = Role::where('name', $name);
        if ($role)
            $role->delete();

        return $this->json();
    }
}
