<?php


namespace App\Lib\Alerting\Provider;


use App\Lib\Alerting\AlertingProviderInterface;
use App\Lib\Alerting\Provider\Entity\Discord;
use Illuminate\Support\Facades\Http;

class DiscordWebhook implements AlertingProviderInterface
{
    const WEBHOOK_URL = 'https://discord.com/api/webhooks/';

    /**
     * @var \Illuminate\Http\Client\PendingRequest
     */
    protected $http_client;

    public function __construct()
    {
        $this->http_client = Http::baseUrl(self::WEBHOOK_URL)
            ->acceptJson();
    }

    /**
     * @param \Throwable $exception
     */
    public function send($exception)
    {
        $this->http_client->post(config('services.discord.webhook.id'), $this->getRequestBody($exception));
    }

    /**
     * @param \Throwable $exception
     * @return array
     */
    private function getRequestBody($exception)
    {
        return Discord::with()->setEmbeds($exception)->toArray();
    }

    public function notify($data)
    {
        $this->http_client->post(config('services.discord.webhook.id'), $data);
    }
}
