<?php

namespace App\Repositories\Admin;

use App\Models\Agent;

class AgentRepository
{
    private $model;

    public function __construct(Agent $model)
    {
        $this->model = $model;
    }

    public function getAll()
    {
        return $this->model->where('verified', 1)->withTrashed();
    }

    public function register($agent_code, $email, $phone_number, $address, $birth, $username, $password)
    {
        return $this->model->create([
            'agent_code' => $agent_code,
            'email' => $email,
            'phone_number' => $phone_number,
            'address' => $address,
            'birth' => $birth,
            'username' => $username,
            'password' => bcrypt($password),
            'verified' => 1,
        ]);
    }

    public function detail($id)
    {
        return $this->model->where('id', $id)->withTrashed()->first();
    }

    public function update(
        $id,
        $referral_pam_id,
        $agent_code,
        $email,
        $phone_number,
        $address,
        $birth,
        $username
    ) {
        return $this->detail($id)->update([
            'referral_pam_id' => $referral_pam_id,
            'agent_code' => $agent_code,
            'email' => $email,
            'phone_number' => $phone_number,
            'address' => $address,
            'birth' => $birth,
            'username' => $username,
        ]);
    }

    public function updatePassword($id, $password)
    {
        return $this->detail($id)->update([
            'password' => bcrypt($password),
        ]);
    }

    public function disable($id)
    {
        return $this->detail($id)->delete();
    }

    public function restore($id)
    {
        return $this->model->onlyTrashed()->where('id', $id)->restore();
    }

    public function indexNotVerified()
    {
        return $this->model->where('verified', 0);
    }

    public function approve($id)
    {
        $data = $this->model->where([
            ['id', $id],
            ['verified', 0]
        ])->first();
        $data->verified = 1;
        $data->save();

        return $data;
    }

    public function reject($id)
    {
        $data = $this->model->where([
            ['id', $id],
            ['verified', 0]
        ])->first();
        $data->forceDelete();

        return $data;
    }
}
