<?php

namespace App\Repositories\Admin;

use App\Models\Schedule;
use Yajra\DataTables\DataTables;

class ScheduleRepository
{
    public $model;

    public function __construct(Schedule $model)
    {
        $this->model = $model;
    }

    public function getAll()
    {
        return $this->model->latest();
    }

    public function createData($title, $speaker, $description, $banner, $time)
    {
        return $this->model->create([
            'title' => $title,
            'speaker' => $speaker,
            'description' => $description,
            'banner' => $banner,
            'time' => $time
        ]);
    }

    public function getDataById($id)
    {
        return $this->model->where('id', $id)->first();
    }

    public function updateData($id, $title, $speaker, $description, $banner, $time)
    {
        return $this->getDataById($id)->update([
            'title' => $title,
            'speaker' => $speaker,
            'description' => $description,
            'banner' => $banner,
            'time' => $time
        ]);
    }

    public function deleteData($id)
    {
        return $this->getDataById($id)->delete();
    }

    public function getDataAnalystHistory($startDate, $endDate)
    {
        $data = $this->model->whereBetween('time', [$startDate, $endDate])
            ->with('history_agents');

        return DataTables::of($data)
        ->addColumn('total', function(Schedule $schedule) {
            return $schedule->history_agents()
                ->get()
                ->groupBy('agent_id')
                ->count();
        })
        ->make();
    }

    public function getDataAnalystHistoryById($id)
    {
        $data = $this->getDataById($id)->history_agents()->with('agent')->get();
        return $data;
    }

    public function getDataAnalystHistoryFilter($startDate, $endDate)
    {
        $data = $this->model->with('history_agents')->whereBetween('time',[$startDate, $endDate]);

        return DataTables::of($data)
            ->addColumn('total', function(Schedule $schedule) {
                return $schedule->history_agents()
                    ->where('status_check', 0)
                    ->get()
                    ->groupBy('agent_id')
                    ->count();
            })
            ->make();
    }

    public function detail_schedule($id)
    {
        $data = $this->getDataById($id);
        return $data;
    }
}
