<?php

namespace App\Services\Admin;

use App\Repositories\Admin\HistoryRepository;
use Illuminate\Support\Carbon;

class HistoryService
{
    protected $history;

    public function __construct(HistoryRepository $history)
    {
        $this->history = $history;
    }

    public function getAll($startDate, $endDate)
    {
        return $this->history->getAll($startDate, $endDate);
    }

    public function getDataById($agent_id, $stat_date, $end_date)
    {
        $data = $this->history->getDataById($agent_id, $stat_date, $end_date);
        $result = $this->checkAttendanceTraining($data);

        return $this->unique_array($result, "title");
    }

    public function detail_person($agent_id, $stat_date, $end_date)
    {
        $data = $this->history->detail_person($agent_id, $stat_date, $end_date);
        $dataSchedule = $this->unique_array($this->checkAttendanceTraining($data['dataSchedule']), "title");

        $check_in = 0;
        $check_out = 0;
        foreach ($dataSchedule as $dt) {
            if ($dt['check_in'] && $dt['check_out']) {
                $check_in += 1;
            } else {
                $check_out += 1;
            }
        }
        $startDate = $this->min_attribute_in_array($dataSchedule, "time");
        $endDate = $this->max_attribute_in_array($dataSchedule, "time");

        $result = [
            'agent_name' => $data['dataPerson']->username,
            'agent_code' => $data['dataPerson']->agent_code,
            'agent_leader' => is_null($data['dataPerson']->referral) ? "None" : $data['dataPerson']->referral->username,
            'date_training_schedule' => Carbon::parse($startDate)->format('d / F / Y') . ' - ' . Carbon::parse($endDate)->format('d / F / Y'),
            'total_training_schedule' => count($dataSchedule),
            'check_in' => $check_in,
            'check_out' => $check_out,
        ];

        return $result;
    }

    public function getDataAttendance()
    {
        return $this->history->getDataAttendance();
    }

    public function getDataAttendanceDetail($agent_id)
    {
        return $this->history->getDataAttendanceDetail($agent_id);
    }

    private function unique_array($array, $key)
    {
        $temp_array = array();
        $i = 0;
        $key_array = array();

        foreach ($array as $val) {
            if (!in_array($val[$key], $key_array)) {
                $key_array[$i] = $val[$key];
                $temp_array[$i] = $val;
            }
            $i++;
        }
        return $temp_array;
    }

    private function checkAttendanceTraining($data)
    {
        $temp = [];

        foreach ($data as $dt) {
            if (count($temp) > 0) {
                foreach ($temp as $key => $value) {
                    if ($value['title'] == $dt->schedule->title && $value['speaker'] == $dt->schedule->speaker) {
                        if ($dt->status_check === 1) {
                            $parseCheckIn = Carbon::parse($temp[$key]['check_in'])->format('m/d/Y H:i:s');
                            $parseCheckOut = Carbon::parse($temp[$key]['check_out'])->format('m/d/Y H:i:s');

                            $dateCheckIn = Carbon::createFromFormat('m/d/Y H:i:s', $parseCheckIn);
                            $dateCheckOut = Carbon::createFromFormat('m/d/Y H:i:s', $parseCheckOut);

                            $result = $dateCheckIn->gte($dateCheckOut);
                            if($result){
                                $temp[$key]['check_in'] = $dt->time_check;
                            }
                        } else if ($dt->status_check === 0) {
                            $temp[$key]['check_out'] = $dt->time_check;
                        }
                    } else {
                        array_push($temp, [
                            'title' => $dt->schedule->title,
                            'speaker' => $dt->schedule->speaker,
                            'time' => $dt->schedule->time,
                            'check_in' => $dt->status_check === 1 ? $dt->time_check : null,
                            'check_out' => $dt->status_check === 0 ? $dt->time_check : null
                        ]);
                    }
                }
            } else {
                array_push($temp, [
                    'title' => $dt->schedule->title,
                    'speaker' => $dt->schedule->speaker,
                    'time' => $dt->schedule->time,
                    'check_in' => $dt->status_check === 1 ? $dt->time_check : null,
                    'check_out' => $dt->status_check === 0 ? $dt->time_check : null
                ]);
            }
        }

        return $temp;
    }

    private function max_attribute_in_array($array, $prop)
    {
        return max(array_map(
            function ($o) use ($prop) {
                return $o[$prop];
            },
            $array
        ));
    }

    private function min_attribute_in_array($array, $prop)
    {
        return min(array_map(
            function ($o) use ($prop) {
                return $o[$prop];
            },
            $array
        ));
    }
}
