<?php

namespace App\Services\Admin\Landing;

use App\Repositories\Admin\Landing\SliderRepository;
use App\Services\Exception\ServiceException;
use File;

class SliderService 
{
    protected $slider;

    public function __construct(SliderRepository $slider)
    {
        $this->slider = $slider;
    }

    public function getAll()
    {
        return $this->slider->getAll();
    }

    public function createData($title, $description, $position, $banner)
    {
        $fileBannerName = time() . '.' . $banner->getClientOriginalExtension();
        $banner->move(public_path('slider'), $fileBannerName);

        return $this->slider->create($title, $description, $position, $fileBannerName);
    }

    public function getDataById($id)
    {
        $data = $this->checkAvailability($id);
        return $data;
    }

    public function updateData($id, $title, $description, $position, $banner)
    {
        $data = $this->checkAvailability($id);

        if(!empty($banner)){
            if(!empty($data->banner)){
                File::delete(public_path('slider/'.$data->banner));
            }

            $fileBannerName = time() . '.' . $banner->getClientOriginalExtension();
            $banner->move(public_path('slider'), $fileBannerName);

            return $this->slider->update($id, $title, $description, $position, $fileBannerName);
        }

        return $this->slider->update($id, $title, $description, $position, $data->banner);
    }

    public function deleteData($id)
    {
        $data = $this->checkAvailability($id);
        $findImages = explode('slider_description/', $data->description);
        foreach($findImages as $image){
            $image = strtok($image, '\">');

            // Image rich text
            if(File::exists(public_path('slider_description/'.$image))){
                File::delete(public_path('slider_description/'.$image));
            }
        }

        // Banner
        if(File::exists(public_path('slider/'.$data->banner))){
            File::delete(public_path('slider/'.$data->banner));
        }
        
        return $this->slider->delete($id);
    }

    public function descriptionImage($file)
    {
        $filename = time().'.'.$file->getClientOriginalExtension();
        $file->move(public_path('slider_description'), $filename);

        return $filename;
    }

    public function updateDisplaySlider($id)
    {
        $data = $this->checkAvailability($id);
        $this->slider->updateDisplay($data->id, $data->display);
    }

    public function checkAvailability($id)
    {
        $data = $this->slider->detail($id);
        if(is_null($data)){
            throw new ServiceException('000');
        }

        return $data;
    }
}
