<?php

namespace App\Services\Admin;

use App\Repositories\Admin\MenuRepository;
use App\Services\Exception\ServiceException;
use File;

class MenuService
{
    protected $menu;

    public function __construct(MenuRepository $menu)
    {
        $this->menu = $menu;
    }

    public function getAll()
    {
        return $this->menu->getAll();
    }

    public function createData($name, $menu_type_id, $parent_id, $position, $description, $banner, $document)
    {
        $fileImage = '';
        $fileDocument = '';

        if(!empty($banner)){
            $fileImage = time().'.'.$banner->getClientOriginalExtension();
            $banner->move(public_path('menu_image'), $fileImage);
        }
        
        if(!empty($document)){
            $fileDocument = time().'.'.$document->getClientOriginalExtension();
            $document->move(public_path('menu_document'), $fileDocument);
        }

        return $this->menu->createData($name, $menu_type_id, $parent_id, $position, $description, $fileImage, $fileDocument);
    }

    public function getDataById($id)
    {
        return $this->menu->getDataById($id);
    }

    public function updateData($id, $name, $menu_type_id, $parent_id, $position, $description, $banner, $document)
    {
        $data = $this->checkAvailability($id);
        if(!empty($banner)){
            if(!empty($data->image)){
                File::delete(public_path('menu_image/'.$data->image));
            }

            $fileImage = time().'.'.$banner->getClientOriginalExtension();
            $banner->move(public_path('menu_image'), $fileImage);
        }

        if(!empty($document)){
            if(!empty($data->document)){
                File::delete(public_path('menu_document/'.$data->document));
            }

            $fileDocument = time().'.'.$document->getClientOriginalExtension();
            $document->move(public_path('menu_document'), $fileDocument);
        }

        return $this->menu->updateData($id, $name, $menu_type_id, $parent_id, $position, $description, !empty($banner) ? $fileImage : $data->image, !empty($document) ? $fileDocument : $data->document);
    }

    public function deleteData($id)
    {
        $data = $this->checkAvailability($id);

        if(!empty($data->image)){
            File::delete(public_path('menu_image/'.$data->image));
        }

        if(!empty($data->document)){
            File::delete(public_path('menu_document/'.$data->document));
        }

        return $this->menu->deleteData($id);
    }


    public function childMenu($id)
    {
        return $this->menu->childMenu($id);
    }

    public function storeDescription($fileDescription)
    {
        $filename = time().'.'.$fileDescription->getClientOriginalExtension();
        $fileDescription->move(public_path('menu_description'), $filename);

        return $filename;
    }

    public function checkAvailability($id)
    {
        $data = $this->menu->getDataById($id);
        if (is_null($data)) {
            throw new ServiceException('000');
        }

        return $data;
    }
}
