<?php

namespace App\Services\Admin;

use App\Repositories\Admin\AgentRepository;
use App\Repositories\Admin\NotificationRepository;
use App\Services\Exception\ServiceException;
use File;

class NotificationService
{
    protected $notification;

    protected $agent;

    public function __construct(
        NotificationRepository $notification,
        AgentRepository $agent
    )
    {
        $this->notification = $notification;
        $this->agent = $agent;
    }

    public function getAll()
    {
        return $this->notification->getAll();
    }

    public function createData($title, $body, $banner)
    {
        $fileBanner = time().'.'.$banner->getClientOriginalExtension();
        $banner->move(public_path('notification'), $fileBanner);

        return $this->notification->createData($title, $body, $fileBanner);
    }

    public function getDataById($id)
    {
        return $this->checkAvailability($id);
    }

    public function updateData($id, $title, $body, $banner)
    {
        $data = $this->checkAvailability($id);
        if(!empty($banner)){
            if(!empty($data->banner)){
                File::delete(public_path('notification/'.$data->banner));
            }

            $fileBanner = time().'.'.$banner->getClientOriginalExtension();
            $banner->move(public_path('notification'), $fileBanner);
        }

        return $this->notification->updateData($id, $title, $body, !empty($banner) ? $fileBanner : $data->banner);
    }

    public function deleteData($id)
    {
        $data = $this->checkAvailability($id);
        if(File::exists(public_path('notification/'.$data->banner))){
            File::delete(public_path('notification/'.$data->banner));
        }

        return $this->notification->deleteData($id);
    }

    public function pushNotificationAndroid($id)
    {
        $SERVER_KEY = config('app.google_secret_android');

        $detailNotification = $this->checkAvailability($id);
        $agents = $this->agent->getAll()->get();

        foreach($agents as $agent){
            $DEVICE_TOKEN = $agent->device_token;
    
            $data = [
                "to" => $DEVICE_TOKEN,
                "notification" => [
                    "title" => $detailNotification->title,
                    "body" => $detailNotification->body
                ],
                "data" => [
                    "type" => "notification",
                    "id" => $detailNotification->id
                ]
            ];
            $dataString = json_encode($data);
    
            $headers = [
                'Authorization: key=' . $SERVER_KEY,
                'Content-Type: application/json',
            ];
    
            $ch = curl_init();
    
            curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);
    
            curl_exec($ch);
            curl_close($ch);
        }

        return true;
    }

    public function pushNotificationIos($id)
    {
        $SERVER_KEY = config('app.google_secret_ios');

        $detailNotification = $this->checkAvailability($id);
        $agents = $this->agent->getAll()->get();

        foreach($agents as $agent){
            $DEVICE_TOKEN = $agent->device_token;
    
            $data = [
                "to" => $DEVICE_TOKEN,
                "notification" => [
                    "title" => $detailNotification->title,
                    "body" => $detailNotification->body
                ],
                "data" => [
                    "type" => "notification",
                    "id" => $detailNotification->id
                ]
            ];
            $dataString = json_encode($data);
    
            $headers = [
                'Authorization: key=' . $SERVER_KEY,
                'Content-Type: application/json',
            ];
    
            $ch = curl_init();
    
            curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/send');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $dataString);
    
            curl_exec($ch);
            curl_close($ch);
        }

        return true;
    }
    
    public function checkAvailability($id)
    {
        $data = $this->notification->getDataById($id);
        if (is_null($data)) {
            throw new ServiceException('000');
        }

        return $data;
    }
}
