<?php

use Monolog\Handler\NullHandler;
use Monolog\Handler\StreamHandler;
use Monolog\Handler\SyslogUdpHandler;

return [

    /*
    |--------------------------------------------------------------------------
    | Default Log Channel
    |--------------------------------------------------------------------------
    |
    | This option defines the default log channel that gets used when writing
    | messages to the logs. The name specified in this option should match
    | one of the channels defined in the "channels" configuration array.
    |
    */

    'default' => env('LOG_CHANNEL', 'stack'),

    /*
    |--------------------------------------------------------------------------
    | Deprecations Log Channel
    |--------------------------------------------------------------------------
    |
    | This option controls the log channel that should be used to log warnings
    | regarding deprecated PHP and library features. This allows you to get
    | your application ready for upcoming major versions of dependencies.
    |
    */

    'deprecations' => env('LOG_DEPRECATIONS_CHANNEL', 'null'),

    /*
    |--------------------------------------------------------------------------
    | Log Channels
    |--------------------------------------------------------------------------
    |
    | Here you may configure the log channels for your application. Out of
    | the box, Laravel uses the Monolog PHP logging library. This gives
    | you a variety of powerful log handlers / formatters to utilize.
    |
    | Available Drivers: "single", "daily", "slack", "syslog",
    |                    "errorlog", "monolog",
    |                    "custom", "stack"
    |
    */

    'channels' => [
        'stack' => [
            'driver' => 'stack',
            'channels' => ['single'],
            'ignore_exceptions' => false,
        ],

        'single' => [
            'driver' => 'single',
            'path' => storage_path('logs/laravel.log'),
            'level' => env('LOG_LEVEL', 'debug'),
        ],

        'daily' => [
            'driver' => 'daily',
            'path' => storage_path('logs/laravel.log'),
            'level' => env('LOG_LEVEL', 'debug'),
            'days' => 14,
        ],

        'slack' => [
            'driver' => 'slack',
            'url' => env('LOG_SLACK_WEBHOOK_URL'),
            'username' => 'Laravel Log',
            'emoji' => ':boom:',
            'level' => env('LOG_LEVEL', 'critical'),
        ],

        'papertrail' => [
            'driver' => 'monolog',
            'level' => env('LOG_LEVEL', 'debug'),
            'handler' => SyslogUdpHandler::class,
            'handler_with' => [
                'host' => env('PAPERTRAIL_URL'),
                'port' => env('PAPERTRAIL_PORT'),
            ],
        ],

        'stderr' => [
            'driver' => 'monolog',
            'level' => env('LOG_LEVEL', 'debug'),
            'handler' => StreamHandler::class,
            'formatter' => env('LOG_STDERR_FORMATTER'),
            'with' => [
                'stream' => 'php://stderr',
            ],
        ],

        'syslog' => [
            'driver' => 'syslog',
            'level' => env('LOG_LEVEL', 'debug'),
        ],

        'errorlog' => [
            'driver' => 'errorlog',
            'level' => env('LOG_LEVEL', 'debug'),
        ],

        'null' => [
            'driver' => 'monolog',
            'handler' => NullHandler::class,
        ],

        'emergency' => [
            'path' => storage_path('logs/laravel.log'),
        ],

        // Admin
        'admin-agentController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/admin/agentController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'admin-menuController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/admin/menuController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'admin-notificationController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/admin/notificationController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'admin-scheduleController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/admin/scheduleController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'admin-sliderController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/admin/sliderController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'admin-userController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/admin/userController.log'),
            'level' => 'debug',
            'days' => 5,
        ],

        // Mobile (landing)
        'landing-agentController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/landing/agentController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'landing-callCenterController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/landing/callCenterController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'landing-kskVedorController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/landing/kskVedorController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'landing-mailController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/landing/mailController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'landing-sliderController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/landing/sliderController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'landing-sosialMediaController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/landing/sosialMediaController.log'),
            'level' => 'debug',
            'days' => 5,
        ],

        // Mobile (Agent)
        'agent-agentController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/agent/agentController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'agent-deviceTokenController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/agent/deviceTokenController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'agent-notificationController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/agent/notificationController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
        'agent-sliderController' => [
            'driver' => 'daily',
            'path' => storage_path('logs/agent/sliderController.log'),
            'level' => 'debug',
            'days' => 5,
        ],
    ],

];
