<?php

use Illuminate\Http\Request;

use Illuminate\Support\Facades\Route;

use App\Http\Controllers\Landing\SosialMediaController;


use App\Http\Controllers\Landing\SliderController as LandingSlider;
use App\Http\Controllers\Landing\KSKVendorController as LandingKSKVendor;
use App\Http\Controllers\Landing\AgentController as LandingAgent;
use App\Http\Controllers\Landing\MailController as LandingMail;
use App\Http\Controllers\Landing\FormController as LandingForm;
use App\Http\Controllers\Landing\CallCenterController as LandingCallCenter;

use App\Http\Controllers\Agent\MenuController as AgentMenu;
use App\Http\Controllers\Agent\SliderController as AgentSlider;
use App\Http\Controllers\Agent\HistoryAgentController as AgentHistory;
use App\Http\Controllers\Agent\ScheduleController as AgentSchedule;
use App\Http\Controllers\Agent\NotificationController as AgentNotification;
use App\Http\Controllers\Agent\AgentController as AgentControllerMobile;
use App\Http\Controllers\Agent\DeviceTokenController;
use App\Http\Controllers\Agent\PopupController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

// Agent
Route::post('agent/login_agent',[AgentControllerMobile::class, 'login'])->name('agent.login');

// Verification
Route::post('agent/verification_forget_password/{agent}',[LandingMail::class, 'verification_forget_password'])->name('agent.verification_forget_password');

// Agent for mobile
Route::group(['prefix' => 'agent', 'as' => 'agent.', 'middleware' => ['auth:sanctum']], function () {
    Route::get('agent_profile', function(Request $request) {
        return auth()->user();
    });

    // Account Agent
    Route::post('account/update/{agent}',[AgentControllerMobile::class, 'update_profile'])->name('agent.update_profile');
    Route::post('device_token',[AgentControllerMobile::class, 'updateFirebaseToken']);

    // Slider
    Route::get('slider/index',[AgentSlider::class, 'index']);
    Route::get('slider/detail/{id}',[AgentSlider::class, 'detail']);

    // Schedule
    Route::get('schedule/index',[AgentSchedule::class, 'index']);
    Route::post('schedule/detail',[AgentSchedule::class, 'detail']);
    Route::get('notification/schedule/index/{limit}',[AgentSchedule::class, 'notificationSchedule']);
    Route::get('notification/schedule/detail/{id}',[AgentSchedule::class, 'detailNotificationSchedule']);
  
    // Menu
    Route::get('menu/get_all',[AgentMenu::class, 'get_all']);
    Route::get('menu/index',[AgentMenu::class, 'index']);
    Route::get('menu/detail/{menu}',[AgentMenu::class, 'detail']);
  
    // Scan
    Route::post('scan/{schedule}',[AgentHistory::class, 'scan']);
    Route::post('check/{schedule}/{status}',[AgentHistory::class, 'check']);
    Route::get('history_check/{limit}',[AgentHistory::class, 'history_check']);

    // Notification
    Route::get('notification/index/{limit}',[AgentNotification::class, 'index'])->name('notification.index');
    Route::get('notification/detail/{id}',[AgentNotification::class, 'detail'])->name('notification.detail');

    // PopUp
    Route::get('pop_up/index',[PopupController::class, 'index']);

    // Logout
    Route::post('logout',[AgentControllerMobile::class, 'logout'])->name('logout');
});

// Landing for mobile
Route::group(['prefix' => 'landing', 'as' => 'landing.'] , function () {
    // Slider
    Route::get('slider/index',[LandingSlider::class, 'index']);
    Route::get('slider/detail/{id}',[LandingSlider::class, 'detail']);

    // KSK
    Route::get('ksk/index',[LandingKSKVendor::class, 'index']);
    Route::get('ksk/detail/{id}',[LandingKSKVendor::class, 'detail']);

    // Form
    Route::get('form/index',[LandingForm::class, 'index']);

    // Call center
    Route::get('call_center/detail',[LandingCallCenter::class, 'detail']);

    // Register Agent
    Route::post('agent/register',[LandingAgent::class, 'register'])->name('agent.register');

    // Forget Account
    Route::post('agent/forget_password',[LandingMail::class, 'forget_password'])->name('agent.forget_password');

    // Landing
    Route::get('sosial_media/index', [SosialMediaController::class, 'index']);
});

require __DIR__ . '/admin.php';